You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by st...@apache.org on 2016/11/19 11:48:00 UTC

svn commit: r1770485 - in /subversion/trunk/subversion: include/private/svn_wc_private.h libsvn_client/conflicts.c libsvn_wc/conflicts.c libsvn_wc/wc_db.h libsvn_wc/wc_db_update_move.c

Author: stsp
Date: Sat Nov 19 11:48:00 2016
New Revision: 1770485

URL: http://svn.apache.org/viewvc?rev=1770485&view=rev
Log:
Rename the conflict resolver's "merge_local_changes" family of functions
to "update_incoming_move". Originally these were intended to be used during
merges as well, but that won't be necessary.

* subversion/include/private/svn_wc_private.h, subversion/libsvn_wc/conflicts.c
  (svn_wc__conflict_tree_merge_local_changes): Rename to ...
  (svn_wc__conflict_tree_update_incoming_move): ... this. Adjust docstring.
   Track rename of svn_wc__db API function.

* subversion/libsvn_client/conflicts.c
  (resolve_incoming_move_dir_merge): Track rename.

* subversion/libsvn_wc/wc_db.h, subversion/libsvn_wc/wc_db_update_move.c
  (merge_local_changes): Rename to ...
  (update_incoming_move): ... this.
  (svn_wc__db_merge_local_changes): Rename to ...
  (svn_wc__db_update_incoming_move): ... this. Track above rename.

Modified:
    subversion/trunk/subversion/include/private/svn_wc_private.h
    subversion/trunk/subversion/libsvn_client/conflicts.c
    subversion/trunk/subversion/libsvn_wc/conflicts.c
    subversion/trunk/subversion/libsvn_wc/wc_db.h
    subversion/trunk/subversion/libsvn_wc/wc_db_update_move.c

Modified: subversion/trunk/subversion/include/private/svn_wc_private.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/private/svn_wc_private.h?rev=1770485&r1=1770484&r2=1770485&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/conflicts.c (original)
+++ subversion/trunk/subversion/libsvn_client/conflicts.c Sat Nov 19 11:48:00 2016
@@ -7152,14 +7152,14 @@ resolve_incoming_move_dir_merge(svn_clie
 
       if (is_modified)
         {
-          err = svn_wc__conflict_tree_merge_local_changes(ctx->wc_ctx,
-                                                          local_abspath,
-                                                          moved_to_abspath,
-                                                          ctx->cancel_func,
-                                                          ctx->cancel_baton,
-                                                          ctx->notify_func2,
-                                                          ctx->notify_baton2,
-                                                          scratch_pool);
+          err = svn_wc__conflict_tree_update_incoming_move(ctx->wc_ctx,
+                                                           local_abspath,
+                                                           moved_to_abspath,
+                                                           ctx->cancel_func,
+                                                           ctx->cancel_baton,
+                                                           ctx->notify_func2,
+                                                           ctx->notify_baton2,
+                                                           scratch_pool);
           if (err)
             goto unlock_wc;
         }

Modified: subversion/trunk/subversion/libsvn_wc/conflicts.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/conflicts.c?rev=1770485&r1=1770484&r2=1770485&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/conflicts.c (original)
+++ subversion/trunk/subversion/libsvn_wc/conflicts.c Sat Nov 19 11:48:00 2016
@@ -3704,14 +3704,14 @@ svn_wc__conflict_tree_update_moved_away_
 }
 
 svn_error_t *
-svn_wc__conflict_tree_merge_local_changes(svn_wc_context_t *wc_ctx,
-                                          const char *local_abspath,
-                                          const char *dest_abspath,
-                                          svn_cancel_func_t cancel_func,
-                                          void *cancel_baton,
-                                          svn_wc_notify_func2_t notify_func,
-                                          void *notify_baton,
-                                          apr_pool_t *scratch_pool)
+svn_wc__conflict_tree_update_incoming_move(svn_wc_context_t *wc_ctx,
+                                           const char *local_abspath,
+                                           const char *dest_abspath,
+                                           svn_cancel_func_t cancel_func,
+                                           void *cancel_baton,
+                                           svn_wc_notify_func2_t notify_func,
+                                           void *notify_baton,
+                                           apr_pool_t *scratch_pool)
 {
   svn_wc_conflict_reason_t local_change;
   svn_wc_conflict_action_t incoming_change;
@@ -3760,13 +3760,12 @@ svn_wc__conflict_tree_merge_local_change
                              svn_dirent_local_style(local_abspath,
                                                     scratch_pool));
 
-  /* Merge local changes. */
-  SVN_ERR(svn_wc__db_merge_local_changes(wc_ctx->db, local_abspath,
-                                         dest_abspath, operation,
-                                         incoming_change, local_change,
-                                         cancel_func, cancel_baton,
-                                         notify_func, notify_baton,
-                                         scratch_pool));
+  SVN_ERR(svn_wc__db_update_incoming_move(wc_ctx->db, local_abspath,
+                                          dest_abspath, operation,
+                                          incoming_change, local_change,
+                                          cancel_func, cancel_baton,
+                                          notify_func, notify_baton,
+                                          scratch_pool));
 
   SVN_ERR(svn_wc__wq_run(wc_ctx->db, local_abspath, cancel_func, cancel_baton,
                          scratch_pool));

Modified: subversion/trunk/subversion/libsvn_wc/wc_db.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db.h?rev=1770485&r1=1770484&r2=1770485&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/wc_db.h (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db.h Sat Nov 19 11:48:00 2016
@@ -3408,17 +3408,17 @@ svn_wc__db_update_moved_away_conflict_vi
    directory at DEST_ABSPATH. This function requires that LOCAL_ABSPATH is
    a directory and a tree-conflict victim. DST_ABSPATH must be a directory. */
 svn_error_t *
-svn_wc__db_merge_local_changes(svn_wc__db_t *db,
-                               const char *local_abspath,
-                               const char *dest_abspath,
-                               svn_wc_operation_t operation,
-                               svn_wc_conflict_action_t action,
-                               svn_wc_conflict_reason_t reason,
-                               svn_cancel_func_t cancel_func,
-                               void *cancel_baton,
-                               svn_wc_notify_func2_t notify_func,
-                               void *notify_baton,
-                               apr_pool_t *scratch_pool);
+svn_wc__db_update_incoming_move(svn_wc__db_t *db,
+                                const char *local_abspath,
+                                const char *dest_abspath,
+                                svn_wc_operation_t operation,
+                                svn_wc_conflict_action_t action,
+                                svn_wc_conflict_reason_t reason,
+                                svn_cancel_func_t cancel_func,
+                                void *cancel_baton,
+                                svn_wc_notify_func2_t notify_func,
+                                void *notify_baton,
+                                apr_pool_t *scratch_pool);
 
 /* LOCAL_ABSPATH is moved to MOVE_DST_ABSPATH.  MOVE_SRC_ROOT_ABSPATH
  * is the root of the move to MOVE_DST_OP_ROOT_ABSPATH.

Modified: subversion/trunk/subversion/libsvn_wc/wc_db_update_move.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/wc_db_update_move.c?rev=1770485&r1=1770484&r2=1770485&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/wc_db_update_move.c (original)
+++ subversion/trunk/subversion/libsvn_wc/wc_db_update_move.c Sat Nov 19 11:48:00 2016
@@ -2191,9 +2191,9 @@ walk_local_changes(node_move_baton_t *nm
   return SVN_NO_ERROR;
 }
 
-/* The body of svn_wc__db_merge_local_changes(). */
+/* The body of svn_wc__db_update_incoming_move(). */
 static svn_error_t *
-merge_local_changes(svn_revnum_t *old_rev,
+update_incoming_move(svn_revnum_t *old_rev,
                     svn_revnum_t *new_rev,
                     svn_wc__db_t *db,
                     svn_wc__db_wcroot_t *wcroot,
@@ -2294,17 +2294,17 @@ merge_local_changes(svn_revnum_t *old_re
 }
 
 svn_error_t *
-svn_wc__db_merge_local_changes(svn_wc__db_t *db,
-                               const char *local_abspath,
-                               const char *dest_abspath,
-                               svn_wc_operation_t operation,
-                               svn_wc_conflict_action_t action,
-                               svn_wc_conflict_reason_t reason,
-                               svn_cancel_func_t cancel_func,
-                               void *cancel_baton,
-                               svn_wc_notify_func2_t notify_func,
-                               void *notify_baton,
-                               apr_pool_t *scratch_pool)
+svn_wc__db_update_incoming_move(svn_wc__db_t *db,
+                                const char *local_abspath,
+                                const char *dest_abspath,
+                                svn_wc_operation_t operation,
+                                svn_wc_conflict_action_t action,
+                                svn_wc_conflict_reason_t reason,
+                                svn_cancel_func_t cancel_func,
+                                void *cancel_baton,
+                                svn_wc_notify_func2_t notify_func,
+                                void *notify_baton,
+                                apr_pool_t *scratch_pool)
 {
   svn_wc__db_wcroot_t *wcroot;
   svn_revnum_t old_rev, new_rev;
@@ -2321,11 +2321,11 @@ svn_wc__db_merge_local_changes(svn_wc__d
   dest_relpath
     = svn_dirent_skip_ancestor(wcroot->abspath, dest_abspath);
 
-  SVN_WC__DB_WITH_TXN(merge_local_changes(&old_rev, &new_rev, db, wcroot,
-                                          local_relpath, dest_relpath,
-                                          operation, action, reason,
-                                          cancel_func, cancel_baton,
-                                          scratch_pool),
+  SVN_WC__DB_WITH_TXN(update_incoming_move(&old_rev, &new_rev, db, wcroot,
+                                           local_relpath, dest_relpath,
+                                           operation, action, reason,
+                                           cancel_func, cancel_baton,
+                                           scratch_pool),
                       wcroot);
 
   /* Send all queued up notifications. */
--- subversion/trunk/subversion/include/private/svn_wc_private.h (original)
+++ subversion/trunk/subversion/include/private/svn_wc_private.h Sat Nov 19 11:48:00 2016
@@ -1894,22 +1894,22 @@ svn_wc__conflict_tree_update_moved_away_
                                              apr_pool_t *scratch_pool);
 
 /* Merge local changes from a tree conflict victim of an incoming deletion
  * to the specified DEST_ABSPATH. Both LOCAL_ABSPATH and DEST_ABSPATH must
  * be directories.
  *
  * Assuming DEST_ABSPATH is the correct destination, this function allows
  * local changes to "follow" incoming moves.
  *
  * @since New in 1.10. */
 svn_error_t *
-svn_wc__conflict_tree_merge_local_changes(svn_wc_context_t *wc_ctx,
-                                          const char *local_abspath,
-                                          const char *dest_abspath,
-                                          svn_cancel_func_t cancel_func,
-                                          void *cancel_baton,
-                                          svn_wc_notify_func2_t notify_func,
-                                          void *notify_baton,
-                                          apr_pool_t *scratch_pool);
+svn_wc__conflict_tree_update_incoming_move(svn_wc_context_t *wc_ctx,
+                                           const char *local_abspath,
+                                           const char *dest_abspath,
+                                           svn_cancel_func_t cancel_func,
+                                           void *cancel_baton,
+                                           svn_wc_notify_func2_t notify_func,
+                                           void *notify_baton,
+                                           apr_pool_t *scratch_pool);
 
 /* Find nodes in the working copy which corresponds to the new location
  * MOVED_TO_REPOS_RELPATH@REV of the tree conflict victim at VICTIM_ABSPATH.
@@ -1894,22 +1894,22 @@ svn_wc__conflict_tree_update_moved_away_
 
 /* Merge local changes from a tree conflict victim of an incoming deletion
- * to the specified DEST_ABSPATH. Both LOCAL_ABSPATH and DEST_ABSPATH must
- * be directories.
+ * to the specified DEST_ABSPATH added during an update. Both LOCAL_ABSPATH
+ * and DEST_ABSPATH must be directories.
  *
@@ -1894,22 +1894,22 @@ svn_wc__conflict_tree_update_moved_away_
  *
- * Assuming DEST_ABSPATH is the correct destination, this function allows
- * local changes to "follow" incoming moves.
+ * Assuming DEST_ABSPATH is the correct move destination, this function
+ * allows local changes to "follow" incoming moves during updates.
  *
  * @since New in 1.10. */

Modified: subversion/trunk/subversion/libsvn_client/conflicts.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/conflicts.c?rev=1770485&r1=1770484&r2=1770485&view=diff
==============================================================================